pub enum CacheWriteErr {
GlyphTooLarge,
NoRoomForWholeQueue,
}Expand description
Returned from Cache::cache_queued.
Variants
GlyphTooLarge
At least one of the queued glyphs is too big to fit into the cache, even if all other glyphs are removed.
NoRoomForWholeQueue
Not all of the requested glyphs can fit into the cache, even if the cache is completely cleared before the attempt.