Struct rusttype::VMetrics [−][src]
The “vertical metrics” of a font at a particular scale. This is useful for calculating the amount of vertical space to give a line of text, and for computing the vertical offset between successive lines.
Fields
ascent: f32The highest point that any glyph in the font extends to above the baseline. Typically positive.
descent: f32The lowest point that any glyph in the font extends to below the baseline. Typically negative.
line_gap: f32The gap to leave between the descent of one line and the ascent of the next. This is of course only a guideline given by the font’s designers.